import eldar_text_art as eta

print(eta.create_banner("ELDAR TEXT ART"))
print(eta.text_to_ascii("Hi"))
print(eta.text_triangle("*", 4))
print(eta.rainbow_text("Colorful"))
print(eta.glitch_text("Python"))
