from setuptools import setup, find_packages

setup(
    name='eldar_text_art',
    version='1.0.0',
    author='Eldar Eliyev',
    author_email='example@email.com',
    description='A creative text and emoji art library by Eldar',
    packages=find_packages(),
    python_requires='>=3.8',
)
